@@ -5,6 +5,7 @@ use {
         pubkey::Pubkey,
         rent::Rent,
         transaction::{Result, TransactionError},
+        transaction_context::TransactionContext,
     },
 };
 
@@ -69,18 +70,44 @@ pub(crate) fn submit_rent_state_metrics(pre_rent_state: &RentState, post_rent_st
 pub(crate) fn check_rent_state(
     pre_rent_state: Option<&RentState>,
     post_rent_state: Option<&RentState>,
-    address: &Pubkey,
-    account: &AccountSharedData,
+    transaction_context: &TransactionContext,
+    index: usize,
     do_support_realloc: bool,
 ) -> Result<()> {
     if let Some((pre_rent_state, post_rent_state)) = pre_rent_state.zip(post_rent_state) {
-        submit_rent_state_metrics(pre_rent_state, post_rent_state);
-        if !solana_sdk::incinerator::check_id(address)
-            && !post_rent_state.transition_allowed_from(pre_rent_state, do_support_realloc)
-        {
-            debug!("Account {:?} not rent exempt, state {:?}", address, account);
-            return Err(TransactionError::InvalidRentPayingAccount);
-        }
+        let expect_msg = "account must exist at TransactionContext index if rent-states are Some";
+        check_rent_state_with_account(
+            pre_rent_state,
+            post_rent_state,
+            transaction_context
+                .get_key_of_account_at_index(index)
+                .expect(expect_msg),
+            &transaction_context
+                .get_account_at_index(index)
+                .expect(expect_msg)
+                .borrow(),
+            do_support_realloc,
+        )?;
+    }
+    Ok(())
+}
+
+pub(crate) fn check_rent_state_with_account(
+    pre_rent_state: &RentState,
+    post_rent_state: &RentState,
+    address: &Pubkey,
+    account_state: &AccountSharedData,
+    do_support_realloc: bool,
+) -> Result<()> {
+    submit_rent_state_metrics(pre_rent_state, post_rent_state);
+    if !solana_sdk::incinerator::check_id(address)
+        && !post_rent_state.transition_allowed_from(pre_rent_state, do_support_realloc)
+    {
+        debug!(
+            "Account {} not rent exempt, state {:?}",
+            address, account_state,
+        );
+        return Err(TransactionError::InvalidRentPayingAccount);
     }
     Ok(())
 }
